import Vue from 'vue';
import Router from 'vue-router';
import _ from 'lodash';

Vue.use(Router);

const router = new Router({
  mode: 'history',
  base: process.env.NODE_ENV === 'development' ? '' : process.env.VUE_APP_ROUTER,
  routes: [
    {
      path: '/login',
      name: 'login',
      component: () => import('../views/login/index.vue'),
    },
    {
      path: '/',
      name: 'index',
      component: () => import('../views/index.vue'),
      children: [
        {
          path: '/test/list',
          name: 'test_list',
          meta: { title: '测试' },
          component: () => import('../views/test/list.vue'),
        },
        {
          path: '/doctor/list',
          name: 'doctor_list',
          meta: { title: '医生管理' },
          component: () => import('../views/doctor/list.vue'),
        },
        {
          path: '/doctor/detail',
          name: 'doctor_detail',
          meta: { title: '医生信息' },
          component: () => import('../views/doctor/detail.vue'),
        },

        {
          path: '/nurse/list',
          name: 'nuser_list',
          meta: { title: '护士管理' },
          component: () => import('../views/nurse/list.vue'),
        },
        {
          path: '/nurse/detail',
          name: 'nurse_detail',
          meta: { title: '护士信息' },
          component: () => import('../views/nurse/detail.vue'),
        },
        {
          path: '/group/list',
          name: '护士信息修改',
          component: () => import('../views/group/list.vue'),
        },
        {
          path: '/group/detail',
          name: '群组信息',
          component: () => import('../views/group/detail.vue'),
        },
        {
          path: '/patient/list',
          name: '病人管理',
          component: () => import('../views/patient/list.vue'),
        },
        {
          path: '/patient/detail',
          name: '病人信息',
          component: () => import('../views/patient/detail.vue'),
        },
        {
          path: '/patient/patientemrs',
          name: '病人信息',
          component: () => import('../views/patient/patientemrs.vue'),
        },
        // 医疗科普
        {
          path: '/news/list',
          name: '医疗科普',
          component: () => import('../views/news/list.vue'),
        },
        {
          path: '/news/detail',
          name: '医疗科普信息修改',
          component: () => import('../views/news/detail.vue'),
        },

        // {
        //   path: '/patient/addpatientemrs',
        //   name: '添加病例',
        //   component: () => import('../views/patient/addpatientemrs.vue'),
        // },
        {
          path: '/doctor/invite',
          name: '邀请医生',
          component: () => import('../views/doctor/invite.vue'),
        },
      ],
    },
    {
      path: '/login',
      name: 'login',
      component: () => import('../views/login/index.vue'),
    },
  ],
});

router.beforeEach((to, from, next) => {
  if (to.name === 'login') next();
  else {
    let user = JSON.parse(sessionStorage.getItem('user'));
    if (_.get(user, `userid`, undefined)) next();
    else next('/login');
  }
});

export default router;
